# genomeplot

## overview

A simple wrapper to `bokeh`, streamlining genome-wide visualisations.

## documentation

https://hardingnj.github.io/genomeplot/

## installation

Either via pip:
`python -m pip install genomeplot`

or from source using `poetry`

## requirements

See `pyproject.toml`
